@@ -2,7 +2,7 @@
 /*
  * gsf-output-gnomevfs.c: gnomevfs based output
  *
- * Copyright (C) 2002-2003 Dom Lachowicz (cinamod@hotmail.com)
+ * Copyright (C) 2002-2004 Dom Lachowicz (cinamod@hotmail.com)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2.1 of the GNU Lesser General Public
@@ -36,35 +36,18 @@ typedef struct {
 
 /**
 * gsf_output_gnomevfs_new :
- * @filename : in utf8.
+ * @text_uri : in utf8.
  * @err	     : optionally NULL.
  *
  * Returns a new file or NULL.
  **/
-GsfOutputGnomeVFS *
-gsf_output_gnomevfs_new (char const *filename, GError **err)
+GsfOutput *
+gsf_output_gnomevfs_new (char const *text_uri, GError **err)
 {
-	GsfOutputGnomeVFS *output;
-	GnomeVFSHandle *handle;
-	GnomeVFSResult res;
-
-	if (filename == NULL) {
-		g_set_error (err, gsf_output_error_id (), 0,
-			     "Filename/URI cannot be NULL");
-		return NULL;
-	} else
-		res = gnome_vfs_open (&handle, filename, GNOME_VFS_OPEN_WRITE);
-
-	if (res != GNOME_VFS_OK) {
-		g_set_error (err, gsf_output_error_id (), (gint) res,
-			     gnome_vfs_result_to_string (res));
-		return NULL;
-	}
-
-	output = g_object_new (GSF_OUTPUT_GNOMEVFS_TYPE, NULL);
-	output->handle = handle;
-
-	return output;
+	GnomeVFSURI *uri = gnome_vfs_uri_new (text_uri);
+	GsfOutput *res = gsf_output_gnomevfs_new_uri (uri, err);
+	gnome_vfs_uri_unref (uri);
+	return res;
 }
 
 /**
@@ -74,7 +57,7 @@ gsf_output_gnomevfs_new (char const *filename, GError **err)
  *
  * Returns a new file or NULL.
  **/
-GsfOutputGnomeVFS *
+GsfOutput *
 gsf_output_gnomevfs_new_uri (GnomeVFSURI * uri, GError **err)
 {
 	GsfOutputGnomeVFS *output;
@@ -85,8 +68,9 @@ gsf_output_gnomevfs_new_uri (GnomeVFSURI * uri, GError **err)
 		g_set_error (err, gsf_output_error_id (), 0,
 			     "Filename/URI cannot be NULL");
 		return NULL;
-	} else
-		res = gnome_vfs_open_uri (&handle, uri, GNOME_VFS_OPEN_WRITE);
+	}
+
+	res = gnome_vfs_open_uri (&handle, uri, GNOME_VFS_OPEN_WRITE|GNOME_VFS_OPEN_RANDOM);
 
 	if (res != GNOME_VFS_OK) {
 		g_set_error (err, gsf_output_error_id (), (gint) res,
@@ -97,7 +81,7 @@ gsf_output_gnomevfs_new_uri (GnomeVFSURI * uri, GError **err)
 	output = g_object_new (GSF_OUTPUT_GNOMEVFS_TYPE, NULL);
 	output->handle = handle;
 
-	return output;
+	return GSF_OUTPUT (output);
 }
 
 static gboolean
