@@ -58,6 +58,8 @@ typedef int mode_t;
 
 #endif /* G_OS_WIN32 */
 
+static GObjectClass *parent_class;
+
 struct _GsfOutputStdio {
 	GsfOutput output;
 
@@ -107,8 +109,9 @@ follow_symlinks (char const *filename, GError **error)
 
 			default:
 				if (error)
-					*error = g_error_new (gsf_output_error_id (), errno,
-							      g_strerror (errno));
+					*error = g_error_new_literal 
+						(gsf_output_error_id (), errno,
+						 g_strerror (errno));
 				g_free (followed_filename);
 				return NULL;
 			}
@@ -137,8 +140,8 @@ follow_symlinks (char const *filename, GError **error)
 
 	/* Too many symlinks */
 	if (error)
-		*error = g_error_new (gsf_output_error_id (), ELOOP,
-				      g_strerror (ELOOP));
+		*error = g_error_new_literal (gsf_output_error_id (), ELOOP,
+					      g_strerror (ELOOP));
 
 	return NULL;
 #else  /* !HAVE_READLINK */
@@ -178,8 +181,9 @@ gsf_output_stdio_new (char const *filename, GError **err)
 		/* FIXME? Race conditions en masse.  */
 		if (access (real_filename, W_OK) != 0) {
 			if (err != NULL)
-				*err = g_error_new (gsf_output_error_id (), errno,
-						    g_strerror (errno));
+				*err = g_error_new_literal
+					(gsf_output_error_id (), errno,
+					 g_strerror (errno));
 			goto failure;
 		}
 	} else {
@@ -218,8 +222,9 @@ gsf_output_stdio_new (char const *filename, GError **err)
 
 	if (fd < 0 || NULL == (file = fdopen (fd, "wb"))) {
 		if (err != NULL)
-			*err = g_error_new (gsf_output_error_id (), errno,
-					    g_strerror (errno));
+			*err = g_error_new_literal
+				(gsf_output_error_id (), errno,
+				 g_strerror (errno));
 		goto failure;
 	}
 
@@ -309,7 +314,6 @@ gsf_output_stdio_close (GsfOutput *output)
 static void
 gsf_output_stdio_finalize (GObject *obj)
 {
-	GObjectClass *parent_class;
 	GsfOutput	*output = (GsfOutput *)obj;
 	GsfOutputStdio	*stdio = GSF_OUTPUT_STDIO (output);
 
@@ -321,9 +325,7 @@ gsf_output_stdio_finalize (GObject *obj)
 	g_free (stdio->temp_filename);
 	stdio->temp_filename = NULL;
 
-	parent_class = g_type_class_peek (GSF_OUTPUT_TYPE);
-	if (parent_class && parent_class->finalize)
-		parent_class->finalize (obj);
+	parent_class->finalize (obj);
 }
 
 static gboolean
@@ -331,19 +333,25 @@ gsf_output_stdio_seek (GsfOutput *output, gsf_off_t offset, GSeekType whence)
 {
 	GsfOutputStdio const *stdio = GSF_OUTPUT_STDIO (output);
 	int stdio_whence = 0;	/* make compiler shut up */
-	gsf_off_t loffset;
+
+#ifndef HAVE_FSEEKO
+	long loffset;
+#else
+	off_t loffset;
+#endif
 
 	g_return_val_if_fail (stdio->file != NULL, 
-		gsf_output_set_error (output, 0, "missing file"));
+			      gsf_output_set_error (output, 0, "missing file"));
 
 	loffset = offset;
 	if ((gsf_off_t) loffset != offset) { /* Check for overflow */
 #ifdef HAVE_FSEEKO
 		g_warning ("offset too large for fseeko");
+		return gsf_output_set_error (output, 0, "offset too large for fseeko");
 #else
 		g_warning ("offset too large for fseek");
+		return gsf_output_set_error (output, 0, "offset too large for fseek");
 #endif
-		return gsf_output_set_error (output, 0, "offset too large for fseeko");
 	}
 	switch (whence) {
 	case G_SEEK_SET : stdio_whence = SEEK_SET;	break;
@@ -353,6 +361,7 @@ gsf_output_stdio_seek (GsfOutput *output, gsf_off_t offset, GSeekType whence)
 		break; /*checked in GsfOutput wrapper */
 	}
 
+	errno = 0;
 #ifdef HAVE_FSEEKO
 	if (0 == fseeko (stdio->file, loffset, stdio_whence))
 		return TRUE;
@@ -388,11 +397,10 @@ gsf_output_stdio_write (GsfOutput *output,
 	return TRUE;
 }
 
-static gboolean
+static gsf_off_t
 gsf_output_stdio_vprintf (GsfOutput *output, char const *fmt, va_list args)
 {
-	GsfOutputStdio *stdio = (GsfOutputStdio *)output;
-	return vfprintf (stdio->file, fmt, args) >= 0;
+	return vfprintf (((GsfOutputStdio *)output)->file, fmt, args);
 }
 
 static void
@@ -414,6 +422,8 @@ gsf_output_stdio_class_init (GObjectClass *gobject_class)
 	output_class->Seek	= gsf_output_stdio_seek;
 	output_class->Write	= gsf_output_stdio_write;
 	output_class->Vprintf	= gsf_output_stdio_vprintf;
+
+	parent_class = g_type_class_peek_parent (gobject_class);
 }
 
 GSF_CLASS (GsfOutputStdio, gsf_output_stdio,
