@@ -29,7 +29,7 @@
 #include <gsf/gsf-shared-memory.h>
 #include <string.h>
 
-#define GET_CLASS(instance) G_TYPE_INSTANCE_GET_CLASS (instance, GSF_STRUCTURED_BLOB_TYPE, GsfStructuredBlobClass)
+static GObjectClass *parent_class;
 
 struct _GsfStructuredBlob {
 	GsfInfile base;
@@ -45,7 +45,6 @@ static void
 blob_finalize (GObject *obj)
 {
 	unsigned i;
-	GObjectClass *parent_class;
 	GsfStructuredBlob *blob = GSF_STRUCTURED_BLOB (obj);
 
 	if (blob->data != NULL) {
@@ -60,9 +59,7 @@ blob_finalize (GObject *obj)
 		blob->children = NULL;
 	}
 
-	parent_class = g_type_class_peek (GSF_INFILE_TYPE);
-	if (parent_class && parent_class->finalize)
-		parent_class->finalize (obj);
+	parent_class->finalize (obj);
 }
 
 static GsfInput *
@@ -188,6 +185,8 @@ gsf_structured_blob_class_init (GObjectClass *gobject_class)
 	infile_class->name_by_index	= blob_name_by_index;
 	infile_class->child_by_index	= blob_child_by_index;
 	infile_class->child_by_name	= blob_child_by_name;
+
+	parent_class = g_type_class_peek_parent (gobject_class);
 }
 
 GSF_CLASS (GsfStructuredBlob, gsf_structured_blob,
